@@ -177,14 +177,14 @@ def cli_check(obj):
 @click.argument("environment", type=click.Choice(("staging", "production")))
 @click.pass_obj
 def cli_id(obj, environment):
-    ID(obj["project"], environment).run()
+    ID(obj["project"], obj["config"], environment).run()
 
 
 @main.command("ip", help="Get the IP addresses of the hosts where the task is running")
 @click.argument("environment", type=click.Choice(("staging", "production")))
 @click.pass_obj
 def cli_ip(obj, environment):
-    IP(obj["project"], environment).run()
+    IP(obj["project"], obj["config"], environment).run()
 
 
 @main.command("generator", help="Generate different files from templates")
