@@ -17,7 +17,9 @@ class CreateBranch:
         self._git = GitHandler(project, config)
 
     def run(self):
-        if self._git.is_dirty():
+        if not self._git.is_detached() and self._git.is_dirty():
+            # Default behaviour is to pull when not detached.
+            # Can't do that with uncommitted changes.
             logger.error("You have some uncommited changes, I can't continue")
             sys.exit(-1)
 
