@@ -28,7 +28,7 @@ class CreateQA:
         qa_projects = get_qa_projects(self._config)
         if self._project not in qa_projects:
             logger.error(
-                f"Il progetto {self._project} non fa parte degli ambienti di QA, niente da fare"
+                f"The {self._project} project is not part of the QA environments, nothing to do"
             )
             sys.exit(0)
 
@@ -42,7 +42,7 @@ class CreateQA:
                 )
             except Exception:
                 logger.error(
-                    "Errore durante l'aggiornamento di prima-twig, per favore esegui manualmente `gem update prima-twig`"
+                    "Error updating prima-twig, please run `gem update prima-twig`"
                 )
                 sys.exit(-1)
 
@@ -51,7 +51,7 @@ class CreateQA:
 
         if youtrack_id:
             if prompt_utils.ask_confirm(
-                f"Ci sono altri progetti da aggiungere al QA che fanno riferimento alla card {youtrack_id}?",
+                f"Are there any other projects to add to the QA that refer to the card {youtrack_id}?",
                 default=False,
             ):
                 twig_arg = self._multi_repo_qa(youtrack_id, qa_projects)
@@ -59,29 +59,29 @@ class CreateQA:
                 twig_arg = self._mono_repo_qa(branch_name)
         else:
             logger.warning(
-                "Non sono riuscito a trovare una issue YouTrack collegata al branch, non e' possibile collegare automaticamente altri progetti a questo QA"
+                "I couldn't find a YouTrack issue linked to the branch, it is not possible to automatically link other projects to this QA"
             )
             logger.warning(
-                "Se vuoi creare il QA con diversi branch su diversi progetti per favore interrompi il comando ed utilizza twig"
+                "If you want to create a QA with different branches on different projects please use twig"
             )
             twig_arg = self._mono_repo_qa(branch_name)
 
         qainit_deploy(twig_arg, self._config)
 
         if youtrack_id:
-            logger.info("Aggiorno la card su youtrack...")
+            logger.info("Updating card on YouTrack...")
             self._youtrack.update_state(
                 youtrack_id, self._config.youtrack["test_state"]
             )
 
         drone_url = self._qainit_drone.get_last_build_url(git.get_username())
         if drone_url:
-            logger.info(f"Puoi seguire la creazione del QA su {drone_url}")
+            logger.info(f"You can follow the creation of the QA at {drone_url}")
 
-        logger.info("Configurazione del QA effettuata con successo!")
+        logger.info("QA setup successful!")
 
     def _multi_repo_qa(self, youtrack_id, qa_projects):
-        logger.info("Cerco gli altri branch su github...")
+        logger.info("Looking for the other branches on GitHub...")
         selected_repos = []
         for repo in [self._github.get_repo(p) for p in qa_projects]:
             print(".", end="", flush=True)
@@ -90,7 +90,7 @@ class CreateQA:
                     selected_repos.append((repo.name, branch))
 
         print(".")
-        logger.info("Progetti trovati:")
+        logger.info("Projects found:")
         for elem in selected_repos:
             logger.info(f"{elem[0]} --> {elem[1].name}")
 
@@ -98,7 +98,7 @@ class CreateQA:
 
     def _mono_repo_qa(self, branch_name):
         logger.info(
-            f"Creo il qa con il progetto {self._project} e branch {branch_name}"
+            f"Creating QA with the project {self._project} and branch {branch_name}"
         )
         gh_branch = self._github.get_repo(self._project).get_branch(branch_name)
         selected_repos = [(self._project, gh_branch)]
