@@ -12,6 +12,7 @@ class Config:
         self.user = {}
         self.youtrack = {}
         self.vault = {}
+        self.aws = {}
         self._config_path_file = os.path.join(home_path, ".suite_py/config.yml")
         self._base_cache_path = os.path.join(home_path, ".suite_py/cache")
 
@@ -41,6 +42,12 @@ class Config:
         for k, v in conf.items():
             setattr(self, k, v)
 
+        # AWS section
+        try:
+            self.aws = conf["aws"]
+        except KeyError:
+            pass
+
     def put_cache(self, key, data):
         with open(os.path.join(self._base_cache_path, key), "w") as cache_file:
             json.dump(data, cache_file)
